@@ -121,8 +121,8 @@ getAvailableStandardDesigns <- function(n) {
 }
 
 getCorrMat <- function(n, type) {
-	m <- contrMat(n, type)
-	m <- m%*%t(m)
+	m <- contrMat(n, type)	
+	m <- m%*%diag(1/sqrt(n))%*%t(m)
 	s <- diag(1/sqrt(diag(m)))
 	r <- s%*%m%*%s
 	return(as.numeric(r))
@@ -144,4 +144,64 @@ nextAvailableName <- function(x) {
 		x <- paste(x, i, sep="")
 	}
 	return(x)
+}
+
+# The following code of regmatches under GPL is taken directly from the R base package. 
+# Copyright (C) 2012 The R Foundation for Statistical Computing
+# It was introduced in R 2.14.0 - but for backward-compatibility we also include it in gMCP.
+
+regmatches <- function (x, m, invert = FALSE) {
+	if (length(x) != length(m)) 
+		stop(gettextf("%s and %s must have the same length", 
+						sQuote("x"), sQuote("m")), domain = NA)
+	ili <- is.list(m)
+	useBytes <- if (ili) 
+				any(unlist(lapply(m, attr, "useBytes")))
+			else any(attr(m, "useBytes"))
+	if (useBytes) {
+		asc <- iconv(x, "latin1", "ASCII")
+		ind <- is.na(asc) | (asc != x)
+		if (any(ind)) 
+			Encoding(x[ind]) <- "bytes"
+	}
+	if (!ili && !invert) {
+		so <- m[ind <- (!is.na(m) & (m > -1L))]
+		eo <- so + attr(m, "match.length")[ind] - 1L
+		return(substring(x[ind], so, eo))
+	}
+	y <- if (invert) {
+				Map(function(u, so, ml) {
+							if ((n <- length(so)) == 1L) {
+								if (is.na(so)) 
+									return(character())
+								else if (so == -1L) 
+									return(u)
+							}
+							beg <- if (n > 1L) {
+										eo <- so + ml - 1L
+										if (any(eo[-n] >= so[-1L])) 
+											stop(gettextf("need non-overlapping matches for %s", 
+															sQuote("invert = TRUE")), domain = NA)
+										c(1L, eo + 1L)
+									}
+									else {
+										c(1L, so + ml)
+									}
+							end <- c(so - 1L, nchar(u))
+							substring(u, beg, end)
+						}, x, m, if (ili) 
+									lapply(m, attr, "match.length")
+								else attr(m, "match.length"), USE.NAMES = FALSE)
+			}
+			else {
+				Map(function(u, so, ml) {
+							if (length(so) == 1L) {
+								if (is.na(so) || (so == -1L)) 
+									return(character())
+							}
+							substring(u, so, so + ml - 1L)
+						}, x, m, lapply(m, attr, "match.length"), USE.NAMES = FALSE)
+			}
+	names(y) <- names(x)
+	y
 }
\ No newline at end of file
