@@ -54,4 +54,10 @@ parse2numeric <- function(graph) {
 	if (is.matrix(graph)) return(m)
 	graph@m <- m
 	return(graph)
+}
+
+isEpsilon <- function(w) {
+	x <- try(eval(parse(text = gsub("\\\\epsilon", 0, w))), silent=TRUE)
+	if ("try-error" %in% class(x)) return(FALSE)
+	return(x==0)
 }
\ No newline at end of file
