@@ -8,9 +8,12 @@ import javax.swing.JCheckBox;
 import javax.swing.JDialog;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
+import javax.swing.JSpinner;
 import javax.swing.JTabbedPane;
 import javax.swing.JTextField;
+import javax.swing.SpinnerNumberModel;
 
+import org.af.gMCP.config.Configuration;
 import org.af.gMCP.gui.dialogs.ColorChooseDialog;
 
 import com.jgoodies.forms.layout.CellConstraints;
@@ -27,6 +30,7 @@ public class UpdateEdge extends JDialog implements ActionListener {
 	GraphView control;
 	JTabbedPane tabbedPane = new JTabbedPane();
 	JCheckBox jcbAnchored = new JCheckBox("Weight is anchored and does not follows nodes when moved.");
+	JSpinner spinner = new JSpinner(new SpinnerNumberModel(2, 1, 10, 1));
 	
 	public UpdateEdge(Edge edge, NetList netzListe, GraphView control) {
 		super(netzListe.control.parent, "Updating Edge from node "+edge.from.getName()+" to "+edge.to.getName(), true);
@@ -34,7 +38,7 @@ public class UpdateEdge extends JDialog implements ActionListener {
 		this.edge = edge;
 		this.netzListe = netzListe;
 		String cols = "5dlu, fill:pref:grow, 5dlu, fill:pref:grow, 5dlu";
-        String rows = "5dlu, pref, 5dlu, pref, 5dlu";
+        String rows = "5dlu, fill:pref:grow, 5dlu, pref, 5dlu";
         
         FormLayout layout = new FormLayout(cols, rows);
         getContentPane().setLayout(layout);
@@ -51,6 +55,7 @@ public class UpdateEdge extends JDialog implements ActionListener {
         getContentPane().add(jb, cc.xy(4, 4));
         
         pack();
+        setSize(Math.max(this.getSize().width, 450), this.getSize().height);
         this.setLocation(300, 300);
         setVisible(true);
 	}
@@ -74,7 +79,9 @@ public class UpdateEdge extends JDialog implements ActionListener {
         
         jcbAnchored.addActionListener(this);
         jcbAnchored.setSelected(edge.isFixed());
-        panel.add(jcbAnchored, cc.xyw(2, 4, 3));
+        if (!Configuration.getInstance().getGeneralConfig().getUnAnchor()) {        
+        	panel.add(jcbAnchored, cc.xyw(2, 4, 3));
+        }
         
 		return panel;
 	}
@@ -90,14 +97,21 @@ public class UpdateEdge extends JDialog implements ActionListener {
         panel.setLayout(layout);
         CellConstraints cc = new CellConstraints();
         
-        panel.add(new JLabel("Color:"), cc.xy(2, 2));
+        int row = 2;
+        panel.add(new JLabel("Color:"), cc.xy(2, row));
 		
         colorLabel.setOpaque(true);
         colorLabel.setBackground(edge.color);
-        panel.add(colorLabel, cc.xy(4, 2));
+        panel.add(colorLabel, cc.xy(4, row));
         
         jbColor.addActionListener(this);
-        panel.add(jbColor, cc.xy(6, 2));
+        panel.add(jbColor, cc.xy(6, row));
+        
+        row += 2;
+        
+        panel.add(new JLabel("Line width:"), cc.xy(2, row));
+		
+        panel.add(spinner, cc.xy(4, row));
         
 		return panel;
 	}
@@ -127,7 +141,9 @@ public class UpdateEdge extends JDialog implements ActionListener {
 			control.getDataTable().getModel().setValueAt(new EdgeWeight(0), netzListe.getNodes().indexOf(edge.from), netzListe.getNodes().indexOf(edge.to));
 			netzListe.removeEdge(edge);			
 		} else {
-			edge.setW(tf.getText());	
+			edge.setW(tf.getText());
+			int n = Integer.parseInt(spinner.getModel().getValue().toString());
+			//TODO Set line width n.
 			control.getDataTable().getModel().setValueAt(new EdgeWeight(tf.getText()), netzListe.getNodes().indexOf(edge.from), netzListe.getNodes().indexOf(edge.to));
 		}
 		netzListe.repaint();
