@@ -1,6 +1,7 @@
 package tests;
 
 import org.af.gMCP.gui.CreateGraphGUI;
+import org.af.gMCP.gui.MenuBarMGraph;
 import org.af.gMCP.gui.RControl;
 import org.af.gMCP.gui.graph.NetList;
 import org.junit.After;
@@ -25,7 +26,8 @@ public class InteractionTest {
     }
 
     @Test
-    public void testReset() {
+    public void testReject() {
+    	((MenuBarMGraph)gui.getJMenuBar()).loadGraph("parallelGatekeeping()");
     	
     }
     
